==> haskell-raw-strings-qq-1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: raw-strings-qq
version: 1.1
id: raw-strings-qq-1.1-IkIcbxEW0hf3HJIHhTAzy9
key: raw-strings-qq-1.1-IkIcbxEW0hf3HJIHhTAzy9
license: BSD-3-Clause
copyright: (c) Mikhail Glushenkov 2013-2015
maintainer: mikhail.glushenkov@gmail.com
author: Mikhail Glushenkov
homepage: https://github.com/23Skidoo/raw-strings-qq
synopsis: Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).
    .
    See @examples/RawRegex.hs@ for a usage example.
category: Text
abi: a22b1db570636f23be889a518a1ee42f
exposed: True
exposed-modules:
    Text.RawString.QQ
import-dirs: /usr/lib/ghc-8.4.3/site-local/raw-strings-qq-1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/raw-strings-qq-1.1
hs-libraries: HSraw-strings-qq-1.1-IkIcbxEW0hf3HJIHhTAzy9
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock
haddock-html: /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-raw-strings-qq-1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: raw-strings-qq
version: 1.1
id: raw-strings-qq-1.1-5Hy7jRGjfv8awYxe90woF
key: raw-strings-qq-1.1-5Hy7jRGjfv8awYxe90woF
license: BSD-3-Clause
copyright: (c) Mikhail Glushenkov 2013-2015
maintainer: mikhail.glushenkov@gmail.com
author: Mikhail Glushenkov
homepage: https://github.com/23Skidoo/raw-strings-qq
synopsis: Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).
    .
    See @examples/RawRegex.hs@ for a usage example.
category: Text
abi: 7477d06c4f9ce3b4d4c214a2d3023143
exposed: True
exposed-modules:
    Text.RawString.QQ
import-dirs: /usr/lib/ghc-8.6.1/site-local/raw-strings-qq-1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/raw-strings-qq-1.1
hs-libraries: HSraw-strings-qq-1.1-5Hy7jRGjfv8awYxe90woF
depends:
    base-4.12.0.0 template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock
haddock-html: /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
